# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-01 07:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0025_userpartnote'),
    ]

    operations = [
        migrations.DeleteModel(
            name='QuestionPrize',
        ),
        migrations.AddField(
            model_name='question',
            name='score',
            field=models.IntegerField(blank=True, null=True, verbose_name='\u7b54\u5bf9\u540e\u5f97\u5206'),
        ),
    ]
